#!/bin/bash

DIR=$(head -n 1 debian/changelog | perl -pe 's#\)##' | perl -pe 's#(\d)-.*#$1#' | perl -pe 's# \(#-#')
VERSION=$(echo $DIR | sed 's/.*-//')

if [ -e $DIR ] ; then
	echo "A file or dir named $DIR exists. Cannot build."
	exit 1
fi

GSHOWTV_VERSION=$(egrep 'my *\$version' gshowtv | sed 's/[^0-9\.]//g')

if [ "$GSHOWTV_VERSION" != "$VERSION" ] ; then
	echo "Changelog version ($VERSION) is not the same as gshowtv version ($GSHOWTV_VERSION)!"
	exit 1
fi

TOOLBAR_CHECK=$(grep toolbar_style gshowtv.glade)
if [ "$TOOLBAR_CHECK" != "" ] ; then
	echo "Toolbar has style set, remove it and retry."
	exit 1
fi

mkdir $DIR

cp AUTHORS KNOWN_ISSUES TODO copyright Makefile gshowtv.desktop publish.sh README gshowtv gshowtv.glade $DIR
mkdir $DIR/debian
mkdir $DIR/pixmaps
mkdir $DIR/po
mkdir $DIR/pvr

cp debian/changelog debian/control debian/dirs debian/files debian/gshowtv.menu debian/install debian/rules $DIR/debian
cp -R doc $DIR/
cp -R pixmaps $DIR
cp -R po $DIR
cp -R pvr $DIR

cd $DIR

rm -fr */CVS
rm -fr */*/CVS

rm -fr po/*.mo

dpkg-buildpackage -rfakeroot

cd ..

echo
echo "Running linda to verify the archive"

linda gshowtv_*.deb

echo

if [ ! -d upload ] ; then
	mkdir upload
else
	rm -fr upload/gshowtv*
fi

mv *.deb upload/
mv *.changes upload/
mv *.tar.gz upload/
mv *.dsc upload/

cp upload/gshowtv*.tar.gz gshowtv-$VERSION.tar.gz

echo "Results are in the upload/ dir and the sf.net tar is in current dir."

